agent

package
v0.0.0-...-eab295c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 1, 2026 License: AGPL-3.0 Imports: 33 Imported by: 0

Documentation

Index

Constants

const (
	AgentService_RegisterAgent_FullMethodName     = "/agent.AgentService/RegisterAgent"
	AgentService_UpdateAgent_FullMethodName       = "/agent.AgentService/UpdateAgent"
	AgentService_DeleteAgent_FullMethodName       = "/agent.AgentService/DeleteAgent"
	AgentService_ListAgents_FullMethodName        = "/agent.AgentService/ListAgents"
	AgentService_AgentStream_FullMethodName       = "/agent.AgentService/AgentStream"
	AgentService_ListAgentCommands_FullMethodName = "/agent.AgentService/ListAgentCommands"
)
const (
	CollectorService_RegisterCollector_FullMethodName  = "/agent.CollectorService/RegisterCollector"
	CollectorService_DeleteCollector_FullMethodName    = "/agent.CollectorService/DeleteCollector"
	CollectorService_ListCollector_FullMethodName      = "/agent.CollectorService/ListCollector"
	CollectorService_CollectorStream_FullMethodName    = "/agent.CollectorService/CollectorStream"
	CollectorService_GetCollectorConfig_FullMethodName = "/agent.CollectorService/GetCollectorConfig"
)
const (
	PanelCollectorService_RegisterCollectorConfig_FullMethodName = "/agent.PanelCollectorService/RegisterCollectorConfig"
)
const (
	PanelService_ProcessCommand_FullMethodName = "/agent.PanelService/ProcessCommand"
)
const (
	PingService_Ping_FullMethodName = "/agent.PingService/Ping"
)

Variables

var (
	AgentCommandStatus_name = map[int32]string{
		0: "NOT_EXECUTED",
		1: "QUEUE",
		2: "PENDING",
		3: "EXECUTED",
		4: "ERROR",
	}
	AgentCommandStatus_value = map[string]int32{
		"NOT_EXECUTED": 0,
		"QUEUE":        1,
		"PENDING":      2,
		"EXECUTED":     3,
		"ERROR":        4,
	}
)

Enum value maps for AgentCommandStatus.

var (
	CollectorModule_name = map[int32]string{
		0: "AS_400",
		1: "UTMSTACK",
	}
	CollectorModule_value = map[string]int32{
		"AS_400":   0,
		"UTMSTACK": 1,
	}
)

Enum value maps for CollectorModule.

var (
	Status_name = map[int32]string{
		0: "ONLINE",
		1: "OFFLINE",
		2: "UNKNOWN",
	}
	Status_value = map[string]int32{
		"ONLINE":  0,
		"OFFLINE": 1,
		"UNKNOWN": 2,
	}
)

Enum value maps for Status.

var (
	ConnectorType_name = map[int32]string{
		0: "AGENT",
		1: "COLLECTOR",
	}
	ConnectorType_value = map[string]int32{
		"AGENT":     0,
		"COLLECTOR": 1,
	}
)

Enum value maps for ConnectorType.

var AgentService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "agent.AgentService",
	HandlerType: (*AgentServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "RegisterAgent",
			Handler:    _AgentService_RegisterAgent_Handler,
		},
		{
			MethodName: "UpdateAgent",
			Handler:    _AgentService_UpdateAgent_Handler,
		},
		{
			MethodName: "DeleteAgent",
			Handler:    _AgentService_DeleteAgent_Handler,
		},
		{
			MethodName: "ListAgents",
			Handler:    _AgentService_ListAgents_Handler,
		},
		{
			MethodName: "ListAgentCommands",
			Handler:    _AgentService_ListAgentCommands_Handler,
		},
	},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "AgentStream",
			Handler:       _AgentService_AgentStream_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
	},
	Metadata: "agent.proto",
}

AgentService_ServiceDesc is the grpc.ServiceDesc for AgentService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var CollectorService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "agent.CollectorService",
	HandlerType: (*CollectorServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "RegisterCollector",
			Handler:    _CollectorService_RegisterCollector_Handler,
		},
		{
			MethodName: "DeleteCollector",
			Handler:    _CollectorService_DeleteCollector_Handler,
		},
		{
			MethodName: "ListCollector",
			Handler:    _CollectorService_ListCollector_Handler,
		},
		{
			MethodName: "GetCollectorConfig",
			Handler:    _CollectorService_GetCollectorConfig_Handler,
		},
	},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "CollectorStream",
			Handler:       _CollectorService_CollectorStream_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
	},
	Metadata: "collector.proto",
}

CollectorService_ServiceDesc is the grpc.ServiceDesc for CollectorService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_agent_proto protoreflect.FileDescriptor
var File_collector_proto protoreflect.FileDescriptor
var File_common_proto protoreflect.FileDescriptor
var PanelCollectorService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "agent.PanelCollectorService",
	HandlerType: (*PanelCollectorServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "RegisterCollectorConfig",
			Handler:    _PanelCollectorService_RegisterCollectorConfig_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "collector.proto",
}

PanelCollectorService_ServiceDesc is the grpc.ServiceDesc for PanelCollectorService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var PanelService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "agent.PanelService",
	HandlerType: (*PanelServiceServer)(nil),
	Methods:     []grpc.MethodDesc{},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "ProcessCommand",
			Handler:       _PanelService_ProcessCommand_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
	},
	Metadata: "agent.proto",
}

PanelService_ServiceDesc is the grpc.ServiceDesc for PanelService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var PingService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "agent.PingService",
	HandlerType: (*PingServiceServer)(nil),
	Methods:     []grpc.MethodDesc{},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "Ping",
			Handler:       _PingService_Ping_Handler,
			ClientStreams: true,
		},
	},
	Metadata: "ping.proto",
}

PingService_ServiceDesc is the grpc.ServiceDesc for PingService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func InitAgentService

func InitAgentService() error

func InitCollectorService

func InitCollectorService()

func InitGrpcServer

func InitGrpcServer()

func RegisterAgentServiceServer

func RegisterAgentServiceServer(s grpc.ServiceRegistrar, srv AgentServiceServer)

func RegisterCollectorServiceServer

func RegisterCollectorServiceServer(s grpc.ServiceRegistrar, srv CollectorServiceServer)

func RegisterPanelCollectorServiceServer

func RegisterPanelCollectorServiceServer(s grpc.ServiceRegistrar, srv PanelCollectorServiceServer)

func RegisterPanelServiceServer

func RegisterPanelServiceServer(s grpc.ServiceRegistrar, srv PanelServiceServer)

func RegisterPingServiceServer

func RegisterPingServiceServer(s grpc.ServiceRegistrar, srv PingServiceServer)

func StartGrpcServer

func StartGrpcServer()

func StreamInterceptor

func StreamInterceptor(srv interface{}, ss grpc.ServerStream, info *grpc.StreamServerInfo, handler grpc.StreamHandler) error

func UnaryInterceptor

func UnaryInterceptor(ctx context.Context, req interface{}, info *grpc.UnaryServerInfo, handler grpc.UnaryHandler) (interface{}, error)

Types

type Agent

type Agent struct {
	Ip             string `protobuf:"bytes,1,opt,name=ip,proto3" json:"ip,omitempty"`
	Hostname       string `protobuf:"bytes,2,opt,name=hostname,proto3" json:"hostname,omitempty"`
	Os             string `protobuf:"bytes,3,opt,name=os,proto3" json:"os,omitempty"`
	Status         Status `protobuf:"varint,4,opt,name=status,proto3,enum=agent.Status" json:"status,omitempty"`
	Platform       string `protobuf:"bytes,5,opt,name=platform,proto3" json:"platform,omitempty"`
	Version        string `protobuf:"bytes,6,opt,name=version,proto3" json:"version,omitempty"`
	AgentKey       string `protobuf:"bytes,7,opt,name=agent_key,json=agentKey,proto3" json:"agent_key,omitempty"`
	Id             uint32 `protobuf:"varint,8,opt,name=id,proto3" json:"id,omitempty"`
	LastSeen       string `protobuf:"bytes,9,opt,name=last_seen,json=lastSeen,proto3" json:"last_seen,omitempty"`
	Mac            string `protobuf:"bytes,10,opt,name=mac,proto3" json:"mac,omitempty"`
	OsMajorVersion string `protobuf:"bytes,11,opt,name=os_major_version,json=osMajorVersion,proto3" json:"os_major_version,omitempty"`
	OsMinorVersion string `protobuf:"bytes,12,opt,name=os_minor_version,json=osMinorVersion,proto3" json:"os_minor_version,omitempty"`
	Aliases        string `protobuf:"bytes,13,opt,name=aliases,proto3" json:"aliases,omitempty"`
	Addresses      string `protobuf:"bytes,14,opt,name=addresses,proto3" json:"addresses,omitempty"`
	// contains filtered or unexported fields
}

func (*Agent) Descriptor deprecated

func (*Agent) Descriptor() ([]byte, []int)

Deprecated: Use Agent.ProtoReflect.Descriptor instead.

func (*Agent) GetAddresses

func (x *Agent) GetAddresses() string

func (*Agent) GetAgentKey

func (x *Agent) GetAgentKey() string

func (*Agent) GetAliases

func (x *Agent) GetAliases() string

func (*Agent) GetHostname

func (x *Agent) GetHostname() string

func (*Agent) GetId

func (x *Agent) GetId() uint32

func (*Agent) GetIp

func (x *Agent) GetIp() string

func (*Agent) GetLastSeen

func (x *Agent) GetLastSeen() string

func (*Agent) GetMac

func (x *Agent) GetMac() string

func (*Agent) GetOs

func (x *Agent) GetOs() string

func (*Agent) GetOsMajorVersion

func (x *Agent) GetOsMajorVersion() string

func (*Agent) GetOsMinorVersion

func (x *Agent) GetOsMinorVersion() string

func (*Agent) GetPlatform

func (x *Agent) GetPlatform() string

func (*Agent) GetStatus

func (x *Agent) GetStatus() Status

func (*Agent) GetVersion

func (x *Agent) GetVersion() string

func (*Agent) ProtoMessage

func (*Agent) ProtoMessage()

func (*Agent) ProtoReflect

func (x *Agent) ProtoReflect() protoreflect.Message

func (*Agent) Reset

func (x *Agent) Reset()

func (*Agent) String

func (x *Agent) String() string

type AgentCommand

type AgentCommand struct {
	CreatedAt     *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
	UpdatedAt     *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=updated_at,json=updatedAt,proto3" json:"updated_at,omitempty"`
	AgentId       uint32                 `protobuf:"varint,3,opt,name=agent_id,json=agentId,proto3" json:"agent_id,omitempty"`
	Command       string                 `protobuf:"bytes,4,opt,name=command,proto3" json:"command,omitempty"`
	CommandStatus AgentCommandStatus     `` /* 131-byte string literal not displayed */
	Result        string                 `protobuf:"bytes,6,opt,name=result,proto3" json:"result,omitempty"`
	ExecutedBy    string                 `protobuf:"bytes,7,opt,name=executed_by,json=executedBy,proto3" json:"executed_by,omitempty"`
	CmdId         string                 `protobuf:"bytes,8,opt,name=cmd_id,json=cmdId,proto3" json:"cmd_id,omitempty"`
	Reason        string                 `protobuf:"bytes,9,opt,name=reason,proto3" json:"reason,omitempty"`
	OriginType    string                 `protobuf:"bytes,10,opt,name=origin_type,json=originType,proto3" json:"origin_type,omitempty"`
	OriginId      string                 `protobuf:"bytes,11,opt,name=origin_id,json=originId,proto3" json:"origin_id,omitempty"`
	// contains filtered or unexported fields
}

func (*AgentCommand) Descriptor deprecated

func (*AgentCommand) Descriptor() ([]byte, []int)

Deprecated: Use AgentCommand.ProtoReflect.Descriptor instead.

func (*AgentCommand) GetAgentId

func (x *AgentCommand) GetAgentId() uint32

func (*AgentCommand) GetCmdId

func (x *AgentCommand) GetCmdId() string

func (*AgentCommand) GetCommand

func (x *AgentCommand) GetCommand() string

func (*AgentCommand) GetCommandStatus

func (x *AgentCommand) GetCommandStatus() AgentCommandStatus

func (*AgentCommand) GetCreatedAt

func (x *AgentCommand) GetCreatedAt() *timestamppb.Timestamp

func (*AgentCommand) GetExecutedBy

func (x *AgentCommand) GetExecutedBy() string

func (*AgentCommand) GetOriginId

func (x *AgentCommand) GetOriginId() string

func (*AgentCommand) GetOriginType

func (x *AgentCommand) GetOriginType() string

func (*AgentCommand) GetReason

func (x *AgentCommand) GetReason() string

func (*AgentCommand) GetResult

func (x *AgentCommand) GetResult() string

func (*AgentCommand) GetUpdatedAt

func (x *AgentCommand) GetUpdatedAt() *timestamppb.Timestamp

func (*AgentCommand) ProtoMessage

func (*AgentCommand) ProtoMessage()

func (*AgentCommand) ProtoReflect

func (x *AgentCommand) ProtoReflect() protoreflect.Message

func (*AgentCommand) Reset

func (x *AgentCommand) Reset()

func (*AgentCommand) String

func (x *AgentCommand) String() string

type AgentCommandStatus

type AgentCommandStatus int32
const (
	AgentCommandStatus_NOT_EXECUTED AgentCommandStatus = 0
	AgentCommandStatus_QUEUE        AgentCommandStatus = 1
	AgentCommandStatus_PENDING      AgentCommandStatus = 2
	AgentCommandStatus_EXECUTED     AgentCommandStatus = 3
	AgentCommandStatus_ERROR        AgentCommandStatus = 4
)

func (AgentCommandStatus) Descriptor

func (AgentCommandStatus) Enum

func (AgentCommandStatus) EnumDescriptor deprecated

func (AgentCommandStatus) EnumDescriptor() ([]byte, []int)

Deprecated: Use AgentCommandStatus.Descriptor instead.

func (AgentCommandStatus) Number

func (AgentCommandStatus) String

func (x AgentCommandStatus) String() string

func (AgentCommandStatus) Type

type AgentRequest

type AgentRequest struct {
	Ip             string `protobuf:"bytes,1,opt,name=ip,proto3" json:"ip,omitempty"`
	Hostname       string `protobuf:"bytes,2,opt,name=hostname,proto3" json:"hostname,omitempty"`
	Os             string `protobuf:"bytes,3,opt,name=os,proto3" json:"os,omitempty"`
	Platform       string `protobuf:"bytes,4,opt,name=platform,proto3" json:"platform,omitempty"`
	Version        string `protobuf:"bytes,5,opt,name=version,proto3" json:"version,omitempty"`
	RegisterBy     string `protobuf:"bytes,6,opt,name=register_by,json=registerBy,proto3" json:"register_by,omitempty"`
	Mac            string `protobuf:"bytes,7,opt,name=mac,proto3" json:"mac,omitempty"`
	OsMajorVersion string `protobuf:"bytes,8,opt,name=os_major_version,json=osMajorVersion,proto3" json:"os_major_version,omitempty"`
	OsMinorVersion string `protobuf:"bytes,9,opt,name=os_minor_version,json=osMinorVersion,proto3" json:"os_minor_version,omitempty"`
	Aliases        string `protobuf:"bytes,10,opt,name=aliases,proto3" json:"aliases,omitempty"`
	Addresses      string `protobuf:"bytes,11,opt,name=addresses,proto3" json:"addresses,omitempty"`
	// contains filtered or unexported fields
}

func (*AgentRequest) Descriptor deprecated

func (*AgentRequest) Descriptor() ([]byte, []int)

Deprecated: Use AgentRequest.ProtoReflect.Descriptor instead.

func (*AgentRequest) GetAddresses

func (x *AgentRequest) GetAddresses() string

func (*AgentRequest) GetAliases

func (x *AgentRequest) GetAliases() string

func (*AgentRequest) GetHostname

func (x *AgentRequest) GetHostname() string

func (*AgentRequest) GetIp

func (x *AgentRequest) GetIp() string

func (*AgentRequest) GetMac

func (x *AgentRequest) GetMac() string

func (*AgentRequest) GetOs

func (x *AgentRequest) GetOs() string

func (*AgentRequest) GetOsMajorVersion

func (x *AgentRequest) GetOsMajorVersion() string

func (*AgentRequest) GetOsMinorVersion

func (x *AgentRequest) GetOsMinorVersion() string

func (*AgentRequest) GetPlatform

func (x *AgentRequest) GetPlatform() string

func (*AgentRequest) GetRegisterBy

func (x *AgentRequest) GetRegisterBy() string

func (*AgentRequest) GetVersion

func (x *AgentRequest) GetVersion() string

func (*AgentRequest) ProtoMessage

func (*AgentRequest) ProtoMessage()

func (*AgentRequest) ProtoReflect

func (x *AgentRequest) ProtoReflect() protoreflect.Message

func (*AgentRequest) Reset

func (x *AgentRequest) Reset()

func (*AgentRequest) String

func (x *AgentRequest) String() string

type AgentService

type AgentService struct {
	UnimplementedAgentServiceServer
	UnimplementedPanelServiceServer

	AgentStreamMap        map[uint]AgentService_AgentStreamServer
	AgentStreamMutex      sync.Mutex
	CacheAgentKey         map[uint]string
	CacheAgentKeyMutex    sync.Mutex
	CommandResultChannel  map[string]chan *CommandResult
	CommandResultChannelM sync.Mutex

	DBConnection *database.DB
}
var (
	AgentServ *AgentService
)

func (*AgentService) AgentStream

func (s *AgentService) AgentStream(stream AgentService_AgentStreamServer) error

func (*AgentService) DeleteAgent

func (s *AgentService) DeleteAgent(ctx context.Context, req *DeleteRequest) (*AuthResponse, error)

func (*AgentService) ListAgentCommands

func (s *AgentService) ListAgentCommands(ctx context.Context, req *ListRequest) (*ListAgentsCommandsResponse, error)

func (*AgentService) ListAgents

func (s *AgentService) ListAgents(ctx context.Context, req *ListRequest) (*ListAgentsResponse, error)

func (*AgentService) ProcessCommand

func (s *AgentService) ProcessCommand(stream PanelService_ProcessCommandServer) error

func (*AgentService) RegisterAgent

func (s *AgentService) RegisterAgent(ctx context.Context, req *AgentRequest) (*AuthResponse, error)

func (*AgentService) UpdateAgent

func (s *AgentService) UpdateAgent(ctx context.Context, req *AgentRequest) (*AuthResponse, error)

type AgentServiceClient

type AgentServiceClient interface {
	RegisterAgent(ctx context.Context, in *AgentRequest, opts ...grpc.CallOption) (*AuthResponse, error)
	UpdateAgent(ctx context.Context, in *AgentRequest, opts ...grpc.CallOption) (*AuthResponse, error)
	DeleteAgent(ctx context.Context, in *DeleteRequest, opts ...grpc.CallOption) (*AuthResponse, error)
	ListAgents(ctx context.Context, in *ListRequest, opts ...grpc.CallOption) (*ListAgentsResponse, error)
	AgentStream(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[BidirectionalStream, BidirectionalStream], error)
	ListAgentCommands(ctx context.Context, in *ListRequest, opts ...grpc.CallOption) (*ListAgentsCommandsResponse, error)
}

AgentServiceClient is the client API for AgentService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type AgentServiceServer

type AgentServiceServer interface {
	RegisterAgent(context.Context, *AgentRequest) (*AuthResponse, error)
	UpdateAgent(context.Context, *AgentRequest) (*AuthResponse, error)
	DeleteAgent(context.Context, *DeleteRequest) (*AuthResponse, error)
	ListAgents(context.Context, *ListRequest) (*ListAgentsResponse, error)
	AgentStream(grpc.BidiStreamingServer[BidirectionalStream, BidirectionalStream]) error
	ListAgentCommands(context.Context, *ListRequest) (*ListAgentsCommandsResponse, error)
	// contains filtered or unexported methods
}

AgentServiceServer is the server API for AgentService service. All implementations must embed UnimplementedAgentServiceServer for forward compatibility.

type AgentService_AgentStreamClient

type AgentService_AgentStreamClient = grpc.BidiStreamingClient[BidirectionalStream, BidirectionalStream]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type AgentService_AgentStreamServer

type AgentService_AgentStreamServer = grpc.BidiStreamingServer[BidirectionalStream, BidirectionalStream]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type AuthResponse

type AuthResponse struct {
	Id  uint32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	Key string `protobuf:"bytes,2,opt,name=key,proto3" json:"key,omitempty"`
	// contains filtered or unexported fields
}

func (*AuthResponse) Descriptor deprecated

func (*AuthResponse) Descriptor() ([]byte, []int)

Deprecated: Use AuthResponse.ProtoReflect.Descriptor instead.

func (*AuthResponse) GetId

func (x *AuthResponse) GetId() uint32

func (*AuthResponse) GetKey

func (x *AuthResponse) GetKey() string

func (*AuthResponse) ProtoMessage

func (*AuthResponse) ProtoMessage()

func (*AuthResponse) ProtoReflect

func (x *AuthResponse) ProtoReflect() protoreflect.Message

func (*AuthResponse) Reset

func (x *AuthResponse) Reset()

func (*AuthResponse) String

func (x *AuthResponse) String() string

type BidirectionalStream

type BidirectionalStream struct {

	// Types that are valid to be assigned to StreamMessage:
	//
	//	*BidirectionalStream_Command
	//	*BidirectionalStream_Result
	StreamMessage isBidirectionalStream_StreamMessage `protobuf_oneof:"stream_message"`
	// contains filtered or unexported fields
}

func (*BidirectionalStream) Descriptor deprecated

func (*BidirectionalStream) Descriptor() ([]byte, []int)

Deprecated: Use BidirectionalStream.ProtoReflect.Descriptor instead.

func (*BidirectionalStream) GetCommand

func (x *BidirectionalStream) GetCommand() *UtmCommand

func (*BidirectionalStream) GetResult

func (x *BidirectionalStream) GetResult() *CommandResult

func (*BidirectionalStream) GetStreamMessage

func (x *BidirectionalStream) GetStreamMessage() isBidirectionalStream_StreamMessage

func (*BidirectionalStream) ProtoMessage

func (*BidirectionalStream) ProtoMessage()

func (*BidirectionalStream) ProtoReflect

func (x *BidirectionalStream) ProtoReflect() protoreflect.Message

func (*BidirectionalStream) Reset

func (x *BidirectionalStream) Reset()

func (*BidirectionalStream) String

func (x *BidirectionalStream) String() string

type BidirectionalStream_Command

type BidirectionalStream_Command struct {
	Command *UtmCommand `protobuf:"bytes,1,opt,name=command,proto3,oneof"`
}

type BidirectionalStream_Result

type BidirectionalStream_Result struct {
	Result *CommandResult `protobuf:"bytes,2,opt,name=result,proto3,oneof"`
}

type Collector

type Collector struct {
	Id           int32           `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	Status       Status          `protobuf:"varint,2,opt,name=status,proto3,enum=agent.Status" json:"status,omitempty"`
	CollectorKey string          `protobuf:"bytes,3,opt,name=collector_key,json=collectorKey,proto3" json:"collector_key,omitempty"`
	Ip           string          `protobuf:"bytes,4,opt,name=ip,proto3" json:"ip,omitempty"`
	Hostname     string          `protobuf:"bytes,5,opt,name=hostname,proto3" json:"hostname,omitempty"`
	Version      string          `protobuf:"bytes,6,opt,name=version,proto3" json:"version,omitempty"`
	Module       CollectorModule `protobuf:"varint,7,opt,name=module,proto3,enum=agent.CollectorModule" json:"module,omitempty"`
	LastSeen     string          `protobuf:"bytes,8,opt,name=last_seen,json=lastSeen,proto3" json:"last_seen,omitempty"`
	// contains filtered or unexported fields
}

func (*Collector) Descriptor deprecated

func (*Collector) Descriptor() ([]byte, []int)

Deprecated: Use Collector.ProtoReflect.Descriptor instead.

func (*Collector) GetCollectorKey

func (x *Collector) GetCollectorKey() string

func (*Collector) GetHostname

func (x *Collector) GetHostname() string

func (*Collector) GetId

func (x *Collector) GetId() int32

func (*Collector) GetIp

func (x *Collector) GetIp() string

func (*Collector) GetLastSeen

func (x *Collector) GetLastSeen() string

func (*Collector) GetModule

func (x *Collector) GetModule() CollectorModule

func (*Collector) GetStatus

func (x *Collector) GetStatus() Status

func (*Collector) GetVersion

func (x *Collector) GetVersion() string

func (*Collector) ProtoMessage

func (*Collector) ProtoMessage()

func (*Collector) ProtoReflect

func (x *Collector) ProtoReflect() protoreflect.Message

func (*Collector) Reset

func (x *Collector) Reset()

func (*Collector) String

func (x *Collector) String() string

type CollectorConfig

type CollectorConfig struct {
	CollectorId string                  `protobuf:"bytes,1,opt,name=collector_id,json=collectorId,proto3" json:"collector_id,omitempty"`
	Groups      []*CollectorConfigGroup `protobuf:"bytes,2,rep,name=groups,proto3" json:"groups,omitempty"`
	RequestId   string                  `protobuf:"bytes,3,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
	// contains filtered or unexported fields
}

func (*CollectorConfig) Descriptor deprecated

func (*CollectorConfig) Descriptor() ([]byte, []int)

Deprecated: Use CollectorConfig.ProtoReflect.Descriptor instead.

func (*CollectorConfig) GetCollectorId

func (x *CollectorConfig) GetCollectorId() string

func (*CollectorConfig) GetGroups

func (x *CollectorConfig) GetGroups() []*CollectorConfigGroup

func (*CollectorConfig) GetRequestId

func (x *CollectorConfig) GetRequestId() string

func (*CollectorConfig) ProtoMessage

func (*CollectorConfig) ProtoMessage()

func (*CollectorConfig) ProtoReflect

func (x *CollectorConfig) ProtoReflect() protoreflect.Message

func (*CollectorConfig) Reset

func (x *CollectorConfig) Reset()

func (*CollectorConfig) String

func (x *CollectorConfig) String() string

type CollectorConfigGroup

type CollectorConfigGroup struct {
	Id               int32                           `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	GroupName        string                          `protobuf:"bytes,2,opt,name=group_name,json=groupName,proto3" json:"group_name,omitempty"`
	GroupDescription string                          `protobuf:"bytes,3,opt,name=group_description,json=groupDescription,proto3" json:"group_description,omitempty"`
	Configurations   []*CollectorGroupConfigurations `protobuf:"bytes,4,rep,name=configurations,proto3" json:"configurations,omitempty"`
	CollectorId      int32                           `protobuf:"varint,5,opt,name=collector_id,json=collectorId,proto3" json:"collector_id,omitempty"`
	// contains filtered or unexported fields
}

func (*CollectorConfigGroup) Descriptor deprecated

func (*CollectorConfigGroup) Descriptor() ([]byte, []int)

Deprecated: Use CollectorConfigGroup.ProtoReflect.Descriptor instead.

func (*CollectorConfigGroup) GetCollectorId

func (x *CollectorConfigGroup) GetCollectorId() int32

func (*CollectorConfigGroup) GetConfigurations

func (x *CollectorConfigGroup) GetConfigurations() []*CollectorGroupConfigurations

func (*CollectorConfigGroup) GetGroupDescription

func (x *CollectorConfigGroup) GetGroupDescription() string

func (*CollectorConfigGroup) GetGroupName

func (x *CollectorConfigGroup) GetGroupName() string

func (*CollectorConfigGroup) GetId

func (x *CollectorConfigGroup) GetId() int32

func (*CollectorConfigGroup) ProtoMessage

func (*CollectorConfigGroup) ProtoMessage()

func (*CollectorConfigGroup) ProtoReflect

func (x *CollectorConfigGroup) ProtoReflect() protoreflect.Message

func (*CollectorConfigGroup) Reset

func (x *CollectorConfigGroup) Reset()

func (*CollectorConfigGroup) String

func (x *CollectorConfigGroup) String() string

type CollectorGroupConfigurations

type CollectorGroupConfigurations struct {
	Id              int32  `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	GroupId         int32  `protobuf:"varint,2,opt,name=group_id,json=groupId,proto3" json:"group_id,omitempty"`
	ConfKey         string `protobuf:"bytes,3,opt,name=conf_key,json=confKey,proto3" json:"conf_key,omitempty"`
	ConfValue       string `protobuf:"bytes,4,opt,name=conf_value,json=confValue,proto3" json:"conf_value,omitempty"`
	ConfName        string `protobuf:"bytes,5,opt,name=conf_name,json=confName,proto3" json:"conf_name,omitempty"`
	ConfDescription string `protobuf:"bytes,6,opt,name=conf_description,json=confDescription,proto3" json:"conf_description,omitempty"`
	ConfDataType    string `protobuf:"bytes,7,opt,name=conf_data_type,json=confDataType,proto3" json:"conf_data_type,omitempty"`
	ConfRequired    bool   `protobuf:"varint,8,opt,name=conf_required,json=confRequired,proto3" json:"conf_required,omitempty"`
	// contains filtered or unexported fields
}

func (*CollectorGroupConfigurations) Descriptor deprecated

func (*CollectorGroupConfigurations) Descriptor() ([]byte, []int)

Deprecated: Use CollectorGroupConfigurations.ProtoReflect.Descriptor instead.

func (*CollectorGroupConfigurations) GetConfDataType

func (x *CollectorGroupConfigurations) GetConfDataType() string

func (*CollectorGroupConfigurations) GetConfDescription

func (x *CollectorGroupConfigurations) GetConfDescription() string

func (*CollectorGroupConfigurations) GetConfKey

func (x *CollectorGroupConfigurations) GetConfKey() string

func (*CollectorGroupConfigurations) GetConfName

func (x *CollectorGroupConfigurations) GetConfName() string

func (*CollectorGroupConfigurations) GetConfRequired

func (x *CollectorGroupConfigurations) GetConfRequired() bool

func (*CollectorGroupConfigurations) GetConfValue

func (x *CollectorGroupConfigurations) GetConfValue() string

func (*CollectorGroupConfigurations) GetGroupId

func (x *CollectorGroupConfigurations) GetGroupId() int32

func (*CollectorGroupConfigurations) GetId

func (*CollectorGroupConfigurations) ProtoMessage

func (*CollectorGroupConfigurations) ProtoMessage()

func (*CollectorGroupConfigurations) ProtoReflect

func (*CollectorGroupConfigurations) Reset

func (x *CollectorGroupConfigurations) Reset()

func (*CollectorGroupConfigurations) String

type CollectorMessages

type CollectorMessages struct {

	// Types that are valid to be assigned to StreamMessage:
	//
	//	*CollectorMessages_Config
	//	*CollectorMessages_Result
	StreamMessage isCollectorMessages_StreamMessage `protobuf_oneof:"stream_message"`
	// contains filtered or unexported fields
}

func (*CollectorMessages) Descriptor deprecated

func (*CollectorMessages) Descriptor() ([]byte, []int)

Deprecated: Use CollectorMessages.ProtoReflect.Descriptor instead.

func (*CollectorMessages) GetConfig

func (x *CollectorMessages) GetConfig() *CollectorConfig

func (*CollectorMessages) GetResult

func (x *CollectorMessages) GetResult() *ConfigKnowledge

func (*CollectorMessages) GetStreamMessage

func (x *CollectorMessages) GetStreamMessage() isCollectorMessages_StreamMessage

func (*CollectorMessages) ProtoMessage

func (*CollectorMessages) ProtoMessage()

func (*CollectorMessages) ProtoReflect

func (x *CollectorMessages) ProtoReflect() protoreflect.Message

func (*CollectorMessages) Reset

func (x *CollectorMessages) Reset()

func (*CollectorMessages) String

func (x *CollectorMessages) String() string

type CollectorMessages_Config

type CollectorMessages_Config struct {
	Config *CollectorConfig `protobuf:"bytes,1,opt,name=config,proto3,oneof"`
}

type CollectorMessages_Result

type CollectorMessages_Result struct {
	Result *ConfigKnowledge `protobuf:"bytes,2,opt,name=result,proto3,oneof"`
}

type CollectorModule

type CollectorModule int32
const (
	CollectorModule_AS_400   CollectorModule = 0
	CollectorModule_UTMSTACK CollectorModule = 1
)

func (CollectorModule) Descriptor

func (CollectorModule) Enum

func (x CollectorModule) Enum() *CollectorModule

func (CollectorModule) EnumDescriptor deprecated

func (CollectorModule) EnumDescriptor() ([]byte, []int)

Deprecated: Use CollectorModule.Descriptor instead.

func (CollectorModule) Number

func (CollectorModule) String

func (x CollectorModule) String() string

func (CollectorModule) Type

type CollectorService

type CollectorService struct {
	UnimplementedCollectorServiceServer
	UnimplementedPanelCollectorServiceServer

	CollectorStreamMap        map[uint]CollectorService_CollectorStreamServer
	CollectorStreamMutex      sync.Mutex
	CollectorConfigsCache     map[uint][]*CollectorConfigGroup
	CollectorConfigsCacheM    sync.Mutex
	CacheCollectorKey         map[uint]string
	CacheCollectorKeyMutex    sync.Mutex
	CollectorPendigConfigChan chan *CollectorConfig
	CollectorTypes            []enum.UTMModule

	DBConnection *database.DB
}
var (
	CollectorServ *CollectorService
)

func (*CollectorService) CollectorStream

func (*CollectorService) DeleteCollector

func (s *CollectorService) DeleteCollector(ctx context.Context, req *DeleteRequest) (*AuthResponse, error)

func (*CollectorService) GetCollectorConfig

func (s *CollectorService) GetCollectorConfig(ctx context.Context, in *ConfigRequest) (*CollectorConfig, error)

func (*CollectorService) ListCollector

func (s *CollectorService) ListCollector(ctx context.Context, req *ListRequest) (*ListCollectorResponse, error)

func (*CollectorService) ProcessPendingConfigs

func (s *CollectorService) ProcessPendingConfigs()

func (*CollectorService) RegisterCollector

func (s *CollectorService) RegisterCollector(ctx context.Context, req *RegisterRequest) (*AuthResponse, error)

func (*CollectorService) RegisterCollectorConfig

func (s *CollectorService) RegisterCollectorConfig(ctx context.Context, in *CollectorConfig) (*ConfigKnowledge, error)

type CollectorServiceClient

type CollectorServiceClient interface {
	RegisterCollector(ctx context.Context, in *RegisterRequest, opts ...grpc.CallOption) (*AuthResponse, error)
	DeleteCollector(ctx context.Context, in *DeleteRequest, opts ...grpc.CallOption) (*AuthResponse, error)
	ListCollector(ctx context.Context, in *ListRequest, opts ...grpc.CallOption) (*ListCollectorResponse, error)
	CollectorStream(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[CollectorMessages, CollectorMessages], error)
	GetCollectorConfig(ctx context.Context, in *ConfigRequest, opts ...grpc.CallOption) (*CollectorConfig, error)
}

CollectorServiceClient is the client API for CollectorService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type CollectorServiceServer

type CollectorServiceServer interface {
	RegisterCollector(context.Context, *RegisterRequest) (*AuthResponse, error)
	DeleteCollector(context.Context, *DeleteRequest) (*AuthResponse, error)
	ListCollector(context.Context, *ListRequest) (*ListCollectorResponse, error)
	CollectorStream(grpc.BidiStreamingServer[CollectorMessages, CollectorMessages]) error
	GetCollectorConfig(context.Context, *ConfigRequest) (*CollectorConfig, error)
	// contains filtered or unexported methods
}

CollectorServiceServer is the server API for CollectorService service. All implementations must embed UnimplementedCollectorServiceServer for forward compatibility.

type CollectorService_CollectorStreamClient

type CollectorService_CollectorStreamClient = grpc.BidiStreamingClient[CollectorMessages, CollectorMessages]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type CollectorService_CollectorStreamServer

type CollectorService_CollectorStreamServer = grpc.BidiStreamingServer[CollectorMessages, CollectorMessages]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type CommandResult

type CommandResult struct {
	AgentId    string                 `protobuf:"bytes,1,opt,name=agent_id,json=agentId,proto3" json:"agent_id,omitempty"`
	Result     string                 `protobuf:"bytes,2,opt,name=result,proto3" json:"result,omitempty"`
	ExecutedAt *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=executed_at,json=executedAt,proto3" json:"executed_at,omitempty"`
	CmdId      string                 `protobuf:"bytes,4,opt,name=cmd_id,json=cmdId,proto3" json:"cmd_id,omitempty"`
	// contains filtered or unexported fields
}

func (*CommandResult) Descriptor deprecated

func (*CommandResult) Descriptor() ([]byte, []int)

Deprecated: Use CommandResult.ProtoReflect.Descriptor instead.

func (*CommandResult) GetAgentId

func (x *CommandResult) GetAgentId() string

func (*CommandResult) GetCmdId

func (x *CommandResult) GetCmdId() string

func (*CommandResult) GetExecutedAt

func (x *CommandResult) GetExecutedAt() *timestamppb.Timestamp

func (*CommandResult) GetResult

func (x *CommandResult) GetResult() string

func (*CommandResult) ProtoMessage

func (*CommandResult) ProtoMessage()

func (*CommandResult) ProtoReflect

func (x *CommandResult) ProtoReflect() protoreflect.Message

func (*CommandResult) Reset

func (x *CommandResult) Reset()

func (*CommandResult) String

func (x *CommandResult) String() string

type ConfigKnowledge

type ConfigKnowledge struct {
	Accepted  string `protobuf:"bytes,1,opt,name=accepted,proto3" json:"accepted,omitempty"`
	RequestId string `protobuf:"bytes,2,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
	// contains filtered or unexported fields
}

func (*ConfigKnowledge) Descriptor deprecated

func (*ConfigKnowledge) Descriptor() ([]byte, []int)

Deprecated: Use ConfigKnowledge.ProtoReflect.Descriptor instead.

func (*ConfigKnowledge) GetAccepted

func (x *ConfigKnowledge) GetAccepted() string

func (*ConfigKnowledge) GetRequestId

func (x *ConfigKnowledge) GetRequestId() string

func (*ConfigKnowledge) ProtoMessage

func (*ConfigKnowledge) ProtoMessage()

func (*ConfigKnowledge) ProtoReflect

func (x *ConfigKnowledge) ProtoReflect() protoreflect.Message

func (*ConfigKnowledge) Reset

func (x *ConfigKnowledge) Reset()

func (*ConfigKnowledge) String

func (x *ConfigKnowledge) String() string

type ConfigRequest

type ConfigRequest struct {
	Module CollectorModule `protobuf:"varint,1,opt,name=module,proto3,enum=agent.CollectorModule" json:"module,omitempty"`
	// contains filtered or unexported fields
}

func (*ConfigRequest) Descriptor deprecated

func (*ConfigRequest) Descriptor() ([]byte, []int)

Deprecated: Use ConfigRequest.ProtoReflect.Descriptor instead.

func (*ConfigRequest) GetModule

func (x *ConfigRequest) GetModule() CollectorModule

func (*ConfigRequest) ProtoMessage

func (*ConfigRequest) ProtoMessage()

func (*ConfigRequest) ProtoReflect

func (x *ConfigRequest) ProtoReflect() protoreflect.Message

func (*ConfigRequest) Reset

func (x *ConfigRequest) Reset()

func (*ConfigRequest) String

func (x *ConfigRequest) String() string

type ConfigStatus

type ConfigStatus int32
const (
	ConfigSent    ConfigStatus = 1
	ConfigPending ConfigStatus = 2
)

type ConnectorType

type ConnectorType int32
const (
	ConnectorType_AGENT     ConnectorType = 0
	ConnectorType_COLLECTOR ConnectorType = 1
)

func (ConnectorType) Descriptor

func (ConnectorType) Enum

func (x ConnectorType) Enum() *ConnectorType

func (ConnectorType) EnumDescriptor deprecated

func (ConnectorType) EnumDescriptor() ([]byte, []int)

Deprecated: Use ConnectorType.Descriptor instead.

func (ConnectorType) Number

func (ConnectorType) String

func (x ConnectorType) String() string

func (ConnectorType) Type

type DeleteRequest

type DeleteRequest struct {
	DeletedBy string `protobuf:"bytes,1,opt,name=deleted_by,json=deletedBy,proto3" json:"deleted_by,omitempty"`
	// contains filtered or unexported fields
}

func (*DeleteRequest) Descriptor deprecated

func (*DeleteRequest) Descriptor() ([]byte, []int)

Deprecated: Use DeleteRequest.ProtoReflect.Descriptor instead.

func (*DeleteRequest) GetDeletedBy

func (x *DeleteRequest) GetDeletedBy() string

func (*DeleteRequest) ProtoMessage

func (*DeleteRequest) ProtoMessage()

func (*DeleteRequest) ProtoReflect

func (x *DeleteRequest) ProtoReflect() protoreflect.Message

func (*DeleteRequest) Reset

func (x *DeleteRequest) Reset()

func (*DeleteRequest) String

func (x *DeleteRequest) String() string

type LastSeenService

type LastSeenService struct {
	UnimplementedPingServiceServer

	CacheAgentLastSeen          map[uint]models.LastSeen
	CacheAgentLastSeenMutex     sync.Mutex
	CacheCollectorLastSeen      map[uint]models.LastSeen
	CacheCollectorLastSeenMutex sync.Mutex

	DBConnection *database.DB
}
var (
	LastSeenServ *LastSeenService

	LastSeenChannel chan models.LastSeen
)

func InitLastSeenService

func InitLastSeenService() *LastSeenService

func (*LastSeenService) GetLastSeenStatus

func (s *LastSeenService) GetLastSeenStatus(id uint, typ string) (Status, string, error)

func (*LastSeenService) InitPingSync

func (s *LastSeenService) InitPingSync()

func (*LastSeenService) Ping

type ListAgentsCommandsResponse

type ListAgentsCommandsResponse struct {
	Rows  []*AgentCommand `protobuf:"bytes,1,rep,name=rows,proto3" json:"rows,omitempty"`
	Total int32           `protobuf:"varint,2,opt,name=total,proto3" json:"total,omitempty"`
	// contains filtered or unexported fields
}

func (*ListAgentsCommandsResponse) Descriptor deprecated

func (*ListAgentsCommandsResponse) Descriptor() ([]byte, []int)

Deprecated: Use ListAgentsCommandsResponse.ProtoReflect.Descriptor instead.

func (*ListAgentsCommandsResponse) GetRows

func (x *ListAgentsCommandsResponse) GetRows() []*AgentCommand

func (*ListAgentsCommandsResponse) GetTotal

func (x *ListAgentsCommandsResponse) GetTotal() int32

func (*ListAgentsCommandsResponse) ProtoMessage

func (*ListAgentsCommandsResponse) ProtoMessage()

func (*ListAgentsCommandsResponse) ProtoReflect

func (*ListAgentsCommandsResponse) Reset

func (x *ListAgentsCommandsResponse) Reset()

func (*ListAgentsCommandsResponse) String

func (x *ListAgentsCommandsResponse) String() string

type ListAgentsResponse

type ListAgentsResponse struct {
	Rows  []*Agent `protobuf:"bytes,1,rep,name=rows,proto3" json:"rows,omitempty"`
	Total int32    `protobuf:"varint,2,opt,name=total,proto3" json:"total,omitempty"`
	// contains filtered or unexported fields
}

func (*ListAgentsResponse) Descriptor deprecated

func (*ListAgentsResponse) Descriptor() ([]byte, []int)

Deprecated: Use ListAgentsResponse.ProtoReflect.Descriptor instead.

func (*ListAgentsResponse) GetRows

func (x *ListAgentsResponse) GetRows() []*Agent

func (*ListAgentsResponse) GetTotal

func (x *ListAgentsResponse) GetTotal() int32

func (*ListAgentsResponse) ProtoMessage

func (*ListAgentsResponse) ProtoMessage()

func (*ListAgentsResponse) ProtoReflect

func (x *ListAgentsResponse) ProtoReflect() protoreflect.Message

func (*ListAgentsResponse) Reset

func (x *ListAgentsResponse) Reset()

func (*ListAgentsResponse) String

func (x *ListAgentsResponse) String() string

type ListCollectorResponse

type ListCollectorResponse struct {
	Rows  []*Collector `protobuf:"bytes,1,rep,name=rows,proto3" json:"rows,omitempty"`
	Total int32        `protobuf:"varint,2,opt,name=total,proto3" json:"total,omitempty"`
	// contains filtered or unexported fields
}

func (*ListCollectorResponse) Descriptor deprecated

func (*ListCollectorResponse) Descriptor() ([]byte, []int)

Deprecated: Use ListCollectorResponse.ProtoReflect.Descriptor instead.

func (*ListCollectorResponse) GetRows

func (x *ListCollectorResponse) GetRows() []*Collector

func (*ListCollectorResponse) GetTotal

func (x *ListCollectorResponse) GetTotal() int32

func (*ListCollectorResponse) ProtoMessage

func (*ListCollectorResponse) ProtoMessage()

func (*ListCollectorResponse) ProtoReflect

func (x *ListCollectorResponse) ProtoReflect() protoreflect.Message

func (*ListCollectorResponse) Reset

func (x *ListCollectorResponse) Reset()

func (*ListCollectorResponse) String

func (x *ListCollectorResponse) String() string

type ListRequest

type ListRequest struct {
	PageNumber  int32  `protobuf:"varint,1,opt,name=page_number,json=pageNumber,proto3" json:"page_number,omitempty"`
	PageSize    int32  `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	SearchQuery string `protobuf:"bytes,3,opt,name=search_query,json=searchQuery,proto3" json:"search_query,omitempty"`
	SortBy      string `protobuf:"bytes,4,opt,name=sort_by,json=sortBy,proto3" json:"sort_by,omitempty"`
	// contains filtered or unexported fields
}

func (*ListRequest) Descriptor deprecated

func (*ListRequest) Descriptor() ([]byte, []int)

Deprecated: Use ListRequest.ProtoReflect.Descriptor instead.

func (*ListRequest) GetPageNumber

func (x *ListRequest) GetPageNumber() int32

func (*ListRequest) GetPageSize

func (x *ListRequest) GetPageSize() int32

func (*ListRequest) GetSearchQuery

func (x *ListRequest) GetSearchQuery() string

func (*ListRequest) GetSortBy

func (x *ListRequest) GetSortBy() string

func (*ListRequest) ProtoMessage

func (*ListRequest) ProtoMessage()

func (*ListRequest) ProtoReflect

func (x *ListRequest) ProtoReflect() protoreflect.Message

func (*ListRequest) Reset

func (x *ListRequest) Reset()

func (*ListRequest) String

func (x *ListRequest) String() string

type PanelCollectorServiceClient

type PanelCollectorServiceClient interface {
	RegisterCollectorConfig(ctx context.Context, in *CollectorConfig, opts ...grpc.CallOption) (*ConfigKnowledge, error)
}

PanelCollectorServiceClient is the client API for PanelCollectorService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type PanelCollectorServiceServer

type PanelCollectorServiceServer interface {
	RegisterCollectorConfig(context.Context, *CollectorConfig) (*ConfigKnowledge, error)
	// contains filtered or unexported methods
}

PanelCollectorServiceServer is the server API for PanelCollectorService service. All implementations must embed UnimplementedPanelCollectorServiceServer for forward compatibility.

type PanelServiceClient

type PanelServiceClient interface {
	ProcessCommand(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[UtmCommand, CommandResult], error)
}

PanelServiceClient is the client API for PanelService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type PanelServiceServer

type PanelServiceServer interface {
	ProcessCommand(grpc.BidiStreamingServer[UtmCommand, CommandResult]) error
	// contains filtered or unexported methods
}

PanelServiceServer is the server API for PanelService service. All implementations must embed UnimplementedPanelServiceServer for forward compatibility.

type PanelService_ProcessCommandClient

type PanelService_ProcessCommandClient = grpc.BidiStreamingClient[UtmCommand, CommandResult]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type PanelService_ProcessCommandServer

type PanelService_ProcessCommandServer = grpc.BidiStreamingServer[UtmCommand, CommandResult]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type PingRequest

type PingRequest struct {
	Type ConnectorType `protobuf:"varint,1,opt,name=type,proto3,enum=agent.ConnectorType" json:"type,omitempty"`
	// contains filtered or unexported fields
}

func (*PingRequest) Descriptor deprecated

func (*PingRequest) Descriptor() ([]byte, []int)

Deprecated: Use PingRequest.ProtoReflect.Descriptor instead.

func (*PingRequest) GetType

func (x *PingRequest) GetType() ConnectorType

func (*PingRequest) ProtoMessage

func (*PingRequest) ProtoMessage()

func (*PingRequest) ProtoReflect

func (x *PingRequest) ProtoReflect() protoreflect.Message

func (*PingRequest) Reset

func (x *PingRequest) Reset()

func (*PingRequest) String

func (x *PingRequest) String() string

type PingResponse

type PingResponse struct {
	Received string `protobuf:"bytes,1,opt,name=received,proto3" json:"received,omitempty"`
	// contains filtered or unexported fields
}

func (*PingResponse) Descriptor deprecated

func (*PingResponse) Descriptor() ([]byte, []int)

Deprecated: Use PingResponse.ProtoReflect.Descriptor instead.

func (*PingResponse) GetReceived

func (x *PingResponse) GetReceived() string

func (*PingResponse) ProtoMessage

func (*PingResponse) ProtoMessage()

func (*PingResponse) ProtoReflect

func (x *PingResponse) ProtoReflect() protoreflect.Message

func (*PingResponse) Reset

func (x *PingResponse) Reset()

func (*PingResponse) String

func (x *PingResponse) String() string

type PingServiceClient

type PingServiceClient interface {
	Ping(ctx context.Context, opts ...grpc.CallOption) (grpc.ClientStreamingClient[PingRequest, PingResponse], error)
}

PingServiceClient is the client API for PingService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type PingServiceServer

type PingServiceServer interface {
	Ping(grpc.ClientStreamingServer[PingRequest, PingResponse]) error
	// contains filtered or unexported methods
}

PingServiceServer is the server API for PingService service. All implementations must embed UnimplementedPingServiceServer for forward compatibility.

type PingService_PingClient

type PingService_PingClient = grpc.ClientStreamingClient[PingRequest, PingResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type PingService_PingServer

type PingService_PingServer = grpc.ClientStreamingServer[PingRequest, PingResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type RegisterRequest

type RegisterRequest struct {
	Ip        string          `protobuf:"bytes,1,opt,name=ip,proto3" json:"ip,omitempty"`
	Hostname  string          `protobuf:"bytes,2,opt,name=hostname,proto3" json:"hostname,omitempty"`
	Version   string          `protobuf:"bytes,3,opt,name=version,proto3" json:"version,omitempty"`
	Collector CollectorModule `protobuf:"varint,4,opt,name=collector,proto3,enum=agent.CollectorModule" json:"collector,omitempty"`
	// contains filtered or unexported fields
}

func (*RegisterRequest) Descriptor deprecated

func (*RegisterRequest) Descriptor() ([]byte, []int)

Deprecated: Use RegisterRequest.ProtoReflect.Descriptor instead.

func (*RegisterRequest) GetCollector

func (x *RegisterRequest) GetCollector() CollectorModule

func (*RegisterRequest) GetHostname

func (x *RegisterRequest) GetHostname() string

func (*RegisterRequest) GetIp

func (x *RegisterRequest) GetIp() string

func (*RegisterRequest) GetVersion

func (x *RegisterRequest) GetVersion() string

func (*RegisterRequest) ProtoMessage

func (*RegisterRequest) ProtoMessage()

func (*RegisterRequest) ProtoReflect

func (x *RegisterRequest) ProtoReflect() protoreflect.Message

func (*RegisterRequest) Reset

func (x *RegisterRequest) Reset()

func (*RegisterRequest) String

func (x *RegisterRequest) String() string

type Status

type Status int32
const (
	Status_ONLINE  Status = 0
	Status_OFFLINE Status = 1
	Status_UNKNOWN Status = 2
)

func (Status) Descriptor

func (Status) Descriptor() protoreflect.EnumDescriptor

func (Status) Enum

func (x Status) Enum() *Status

func (Status) EnumDescriptor deprecated

func (Status) EnumDescriptor() ([]byte, []int)

Deprecated: Use Status.Descriptor instead.

func (Status) Number

func (x Status) Number() protoreflect.EnumNumber

func (Status) String

func (x Status) String() string

func (Status) Type

func (Status) Type() protoreflect.EnumType

type UnimplementedAgentServiceServer

type UnimplementedAgentServiceServer struct{}

UnimplementedAgentServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAgentServiceServer) DeleteAgent

func (UnimplementedAgentServiceServer) ListAgentCommands

func (UnimplementedAgentServiceServer) ListAgents

func (UnimplementedAgentServiceServer) RegisterAgent

func (UnimplementedAgentServiceServer) UpdateAgent

type UnimplementedCollectorServiceServer

type UnimplementedCollectorServiceServer struct{}

UnimplementedCollectorServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedCollectorServiceServer) CollectorStream

func (UnimplementedCollectorServiceServer) DeleteCollector

func (UnimplementedCollectorServiceServer) GetCollectorConfig

func (UnimplementedCollectorServiceServer) ListCollector

func (UnimplementedCollectorServiceServer) RegisterCollector

type UnimplementedPanelCollectorServiceServer

type UnimplementedPanelCollectorServiceServer struct{}

UnimplementedPanelCollectorServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedPanelCollectorServiceServer) RegisterCollectorConfig

type UnimplementedPanelServiceServer

type UnimplementedPanelServiceServer struct{}

UnimplementedPanelServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedPanelServiceServer) ProcessCommand

type UnimplementedPingServiceServer

type UnimplementedPingServiceServer struct{}

UnimplementedPingServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedPingServiceServer) Ping

type UnsafeAgentServiceServer

type UnsafeAgentServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAgentServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AgentServiceServer will result in compilation errors.

type UnsafeCollectorServiceServer

type UnsafeCollectorServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeCollectorServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CollectorServiceServer will result in compilation errors.

type UnsafePanelCollectorServiceServer

type UnsafePanelCollectorServiceServer interface {
	// contains filtered or unexported methods
}

UnsafePanelCollectorServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PanelCollectorServiceServer will result in compilation errors.

type UnsafePanelServiceServer

type UnsafePanelServiceServer interface {
	// contains filtered or unexported methods
}

UnsafePanelServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PanelServiceServer will result in compilation errors.

type UnsafePingServiceServer

type UnsafePingServiceServer interface {
	// contains filtered or unexported methods
}

UnsafePingServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PingServiceServer will result in compilation errors.

type UtmCommand

type UtmCommand struct {
	AgentId    string `protobuf:"bytes,1,opt,name=agent_id,json=agentId,proto3" json:"agent_id,omitempty"`
	Command    string `protobuf:"bytes,2,opt,name=command,proto3" json:"command,omitempty"`
	ExecutedBy string `protobuf:"bytes,3,opt,name=executed_by,json=executedBy,proto3" json:"executed_by,omitempty"`
	CmdId      string `protobuf:"bytes,4,opt,name=cmd_id,json=cmdId,proto3" json:"cmd_id,omitempty"`
	OriginType string `protobuf:"bytes,5,opt,name=origin_type,json=originType,proto3" json:"origin_type,omitempty"`
	OriginId   string `protobuf:"bytes,6,opt,name=origin_id,json=originId,proto3" json:"origin_id,omitempty"`
	Reason     string `protobuf:"bytes,7,opt,name=reason,proto3" json:"reason,omitempty"`
	Shell      string `protobuf:"bytes,8,opt,name=shell,proto3" json:"shell,omitempty"` // Shell to execute command: "cmd", "powershell" (Windows), "sh", "bash" (Linux/macOS). Empty = default
	// contains filtered or unexported fields
}

func (*UtmCommand) Descriptor deprecated

func (*UtmCommand) Descriptor() ([]byte, []int)

Deprecated: Use UtmCommand.ProtoReflect.Descriptor instead.

func (*UtmCommand) GetAgentId

func (x *UtmCommand) GetAgentId() string

func (*UtmCommand) GetCmdId

func (x *UtmCommand) GetCmdId() string

func (*UtmCommand) GetCommand

func (x *UtmCommand) GetCommand() string

func (*UtmCommand) GetExecutedBy

func (x *UtmCommand) GetExecutedBy() string

func (*UtmCommand) GetOriginId

func (x *UtmCommand) GetOriginId() string

func (*UtmCommand) GetOriginType

func (x *UtmCommand) GetOriginType() string

func (*UtmCommand) GetReason

func (x *UtmCommand) GetReason() string

func (*UtmCommand) GetShell

func (x *UtmCommand) GetShell() string

func (*UtmCommand) ProtoMessage

func (*UtmCommand) ProtoMessage()

func (*UtmCommand) ProtoReflect

func (x *UtmCommand) ProtoReflect() protoreflect.Message

func (*UtmCommand) Reset

func (x *UtmCommand) Reset()

func (*UtmCommand) String

func (x *UtmCommand) String() string

Jump to