Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetBDGZLogs ¶
func GetBDGZLogs(config *types.ConfigurationSection) http.HandlerFunc
GetBDGZLogs gets the Bitdefender Api Push logs and sends them to the syslog server
func ServerUp ¶
func ServerUp(cnf *types.ConfigurationSection, certsPath string)
ServerUp raises the connector that will receive the data and process it so that it is sent to the syslog server
Types ¶
type EpsSyslogHelper ¶
type EpsSyslogHelper struct {
// contains filtered or unexported fields
}
func (*EpsSyslogHelper) Init ¶
func (g *EpsSyslogHelper) Init()
Initialing connection with syslogServer
func (*EpsSyslogHelper) SentToSyslog ¶
func (g *EpsSyslogHelper) SentToSyslog(config *types.ConfigurationSection, events []string)
SentToSyslog send event by event to syslog server
Click to show internal directories.
Click to hide internal directories.